# crawfish

## Documentation

### Install

```bash
pip install django-crawfish
```

## Development

Install package dependencies:

```bash
pip install -e .
```

Install dev dependencies:

```bash
pip install -e .[dev]
```


